package com.ruoyi.abuwx.mapper;

import com.ruoyi.abuwx.domain.QuestionTask;

import java.util.List;

/**
 * 每日答题任务管理Mapper接口
 *
 * @author lujie
 * @date 2025-01-07
 */
public interface QuestionTaskMapper {
    /**
     * 查询每日答题任务管理
     *
     * @param id 每日答题任务管理主键
     * @return 每日答题任务管理
     */
    public QuestionTask selectQuestionTaskById(Long id);

    /**
     * 查询每日答题任务管理列表
     *
     * @param questionTask 每日答题任务管理
     * @return 每日答题任务管理集合
     */
    public List<QuestionTask> selectQuestionTaskList(QuestionTask questionTask);

    /**
     * 新增每日答题任务管理
     *
     * @param questionTask 每日答题任务管理
     * @return 结果
     */
    public int insertQuestionTask(QuestionTask questionTask);

    /**
     * 修改每日答题任务管理
     *
     * @param questionTask 每日答题任务管理
     * @return 结果
     */
    public int updateQuestionTask(QuestionTask questionTask);

    /**
     * 删除每日答题任务管理
     *
     * @param id 每日答题任务管理主键
     * @return 结果
     */
    public int deleteQuestionTaskById(Long id);

    /**
     * 批量删除每日答题任务管理
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteQuestionTaskByIds(Long[] ids);
}
